/*
 *  clip_beos.cpp - Clipboard handling, BeOS implementation
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#include <AppKit.h>
#include <support/UTF8.h>

#include "sysdeps.h"
#include "clip.h"

#define DEBUG 1
#include "debug.h"


/*
 *  Initialization
 */

void ClipInit(void)
{
}


/*
 *  Deinitialization
 */

void ClipExit(void)
{
}


/*
 *  Mac application wrote to clipboard
 */

void PutScrap(uint32 type, void *scrap, int32 length)
{
	D(bug("PutScrap type %08lx, data %08lx, length %ld\n", type, scrap, length));
	if (length <= 0)
		return;

	switch (type) {
		case 'TEXT':
			D(bug(" clipping TEXT\n"));
			if (be_clipboard->Lock()) {
				be_clipboard->Clear();
				BMessage *clipper = be_clipboard->Data(); 
	
				// Convert text from Mac charset to UTF-8
				int32 dest_length = length*3;
				int32 state = 0;
				char *buf = new char[dest_length];
				if (convert_to_utf8(B_MAC_ROMAN_CONVERSION, (char *)scrap, &length, buf, &dest_length, &state) == B_OK) {
					for (int i=0; i<dest_length; i++)
						if (buf[i] == 13)
							buf[i] = 10;
	
					// Add text to Be clipboard
					clipper->AddData("text/plain", B_MIME_TYPE, buf, dest_length); 
					be_clipboard->Commit();
				}
				delete[] buf;
				be_clipboard->Unlock();
			}
			break;
	}
}
