/*
 *  prefs_beos.cpp - Preferences handling, BeOS specific stuff
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#include <StorageKit.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "sysdeps.h"
#include "prefs.h"
#include "main.h"


// Platform-specific preferences items
prefs_desc platform_prefs_items[] = {
	{"powerrom", TYPE_STRING, false},	// Path of PowerMac ROM (powerrom_cpu.cpp)
	{NULL, TYPE_END, false}	// End of list
};


// Preferences file name and path
const char PREFS_FILE_NAME[] = "BasiliskII_prefs";
static BPath prefs_path;


/*
 *  Load preferences from settings file
 */

void LoadPrefs(void)
{
	// Construct prefs path
	find_directory(B_USER_SETTINGS_DIRECTORY, &prefs_path, true);
	prefs_path.Append(PREFS_FILE_NAME);

	// Read preferences from settings file
	FILE *f = fopen(prefs_path.Path(), "r");
	if (f != NULL) {

		// Prefs file found, load settings
		LoadPrefsFromStream(f);
		fclose(f);

	} else {

		// No prefs file, save defaults
		SavePrefs();
	}
}


/*
 *  Save preferences to settings file
 */

void SavePrefs(void)
{
	FILE *f;
	if ((f = fopen(prefs_path.Path(), "w")) != NULL) {
		SavePrefsToStream(f);
		fclose(f);
	}
}
