/*
 *  timer_beos.cpp - Time Manager emulation, BeOS specific stuff
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#include <KernelKit.h>

#include "sysdeps.h"
#include "timer.h"

#define DEBUG 0
#include "debug.h"


/*
 *  Return microseconds since boot (64 bit)
 */

void Microseconds(uint32 &hi, uint32 &lo)
{
	D(bug("Microseconds\n"));
	bigtime_t time = system_time();
	hi = time >> 32;
	lo = time;
}


/*
 *  Get current time
 */

void timer_current_time(tm_time_t &t)
{
	t = system_time();
}


/*
 *  Add times
 */

void timer_add_time(tm_time_t &res, tm_time_t a, tm_time_t b)
{
	res = a + b;
}


/*
 *  Subtract times
 */

void timer_sub_time(tm_time_t &res, tm_time_t a, tm_time_t b)
{
	res = a - b;
}


/*
 *  Compare times (<0: a < b, =0: a = b, >0: a > b)
 */

int timer_cmp_time(tm_time_t a, tm_time_t b)
{
	tm_time_t r = a - b;
	return r < 0 ? -1 : (r > 0 ? 1 : 0);
}


/*
 *  Convert Mac time value (>0: microseconds, <0: microseconds) to tm_time_t
 */

void timer_mac2host_time(tm_time_t &res, int32 mactime)
{
	if (mactime > 0)
		res = mactime * 1000;	// Time in milliseconds
	else
		res = -mactime;			// Time in negative microseconds
}


/*
 *  Convert positive tm_time_t to Mac time value (>0: microseconds, <0: microseconds)
 *  A negative input value for hosttime results in a zero return value
 *  As long as the microseconds value fits in 32 bit, it must not be converted to milliseconds!
 */

int32 timer_host2mac_time(tm_time_t hosttime)
{
	if (hosttime < 0)
		return 0;
	else if (hosttime > 0x7fffffff)
		return hosttime / 1000;	// Time in milliseconds
	else
		return -hosttime;		// Time in negative microseconds
}
