/*
 *  prefs_windows.cpp - Preferences handling for Win32
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#include <stdio.h>
#include <stdlib.h>

#include "sysdeps.h"
#include "prefs.h"


// Platform-specific preferences items
prefs_desc platform_prefs_items[] = {
	{"replacescsi", TYPE_STRING, true},		// replacescsi "HP" "CD-Writer+ 7100" "PHILIPS" "CDD3600"
	{"disablescsi", TYPE_STRING, true},		// disablescsi "TOSHIBA" "CD-ROM XM-6202B"
	{"nofloppyboot", TYPE_BOOLEAN, false},
	{"noscsi", TYPE_BOOLEAN, false},
	{NULL, TYPE_END, false}	// End of list
};


// Prefs file name and path
const char PREFS_FILE_NAME[] = "BasiliskII_prefs";
static char prefs_path[_MAX_PATH];


static void prefs_get_ini_path( char *path, int sz )
{
	if(!*prefs_path) {
		GetCurrentDirectory(sz,prefs_path);
		if(strlen(prefs_path) > 0 && prefs_path[strlen(prefs_path)-1] != '\\') strcat(prefs_path,"\\");
		strcat( prefs_path, PREFS_FILE_NAME );
	}
	memset( path, 0, sz );
	strncpy( path, prefs_path, sz );
}


/*
 *  Load preferences from settings file
 */

void LoadPrefs(void)
{
	char path[_MAX_PATH];

	prefs_get_ini_path(path,sizeof(path));

	// Read preferences from settings file
	FILE *f = fopen(path, "r");
	if (f != NULL) {
		// Prefs file found, load settings
		LoadPrefsFromStream(f);
		fclose(f);
	} else {
		// No prefs file, save defaults
		SavePrefs();
	}
}


/*
 *  Save preferences to settings file
 */

void SavePrefs(void)
{
	char path[_MAX_PATH];
	FILE *f;

	prefs_get_ini_path(path,sizeof(path));

	if ((f = fopen(path, "w")) != NULL) {
		SavePrefsToStream(f);
		fclose(f);
	}
}
