/*
 *  sysdeps.h - System dependent definitions for Unix
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#ifndef _SYSDEPS_H_
#define _SYSDEPS_H_


// Some compiler may use different variable, and we need this.
#ifndef WIN32
#define WIN32
#endif


// If you undefine this, you will lose NT waitable timers.
// Must be before <winnt.h>
#ifndef _WIN32_WINNT
#define _WIN32_WINNT 0x0400
#else
#if(_WIN32_WINNT < 0x0400)
#undef _WIN32_WINNT
#define _WIN32_WINNT 0x0400
#endif
#endif


#ifndef _DEBUG
#define WIN32_ASM_OPTIMIZATIONS
#endif


#include <sys/types.h>
#include <time.h>
#include <assert.h>
#include <stdio.h>
#include <windows.h>
#include <winnt.h>


// Are the Mac and the host address space the same?
// Do not define REAL_ADDRESSING under windows unless 
// you do some serious implementation first
#define REAL_ADDRESSING 0

// Are we using a 68k emulator or the real thing?
#define EMULATED_68K 1

// Is the Mac ROM write protected?
#define ROM_IS_WRITE_PROTECTED 1

// Data types
typedef unsigned char uint8;
typedef signed char int8;
typedef unsigned short uint16;
typedef signed short int16;
typedef unsigned long uint32;
typedef signed long int32;

#define true TRUE
#define false FALSE
typedef __int64 longlong;

#ifdef __SC__ //For Symantec C++
typedef BOOL bool;
#endif

// Time data type for Time Manager emulation
typedef __int64 tm_time_t;

// UAE CPU data types
#define uae_s8 int8
#define uae_u8 uint8
#define uae_s16 int16
#define uae_u16 uint16
#define uae_s32 int32
#define uae_u32 uint32
typedef uae_u32 uaecptr;

// Endianess
#define LITTLE_ENDIAN
#define CAN_ACCESS_UNALIGNED

// UAE CPU defines
#ifdef LITTLE_ENDIAN

// TODO: rewrite these for speed
#ifdef __i386__
static inline uae_u32 do_get_mem_long(uae_u32 *a) {uint32 retval; __asm__ ("bswapl %0" : "=r" (retval) : "0" (*a) : "cc"); return retval;}
static inline uae_u16 do_get_mem_word(uae_u16 *a) {uint32 retval; __asm__ ("xorl %k0,%k0\n\tmovw %w1,%w0\n\trolw $8,%w0" : "=&r" (retval) : "m" (*a) : "cc"); return retval;}
static inline uae_u8 do_get_mem_byte(uae_u8 *a) {return *a;}
static inline void do_put_mem_long(uae_u32 *a, uae_u32 v) {__asm__ ("bswapl %0" : "=r" (v) : "0" (v) : "cc"); *a = v;}
static inline void do_put_mem_word(uae_u16 *a, uae_u16 v) {__asm__ ("rolw $8,%0" : "=r" (v) : "0" (v) : "cc"); *a = v;}
static inline void do_put_mem_byte(uae_u8 *a, uae_u8 v) {*a = v;}
#elif defined(CAN_ACCESS_UNALIGNED)
static inline uae_u32 do_get_mem_long(uae_u32 *a) {uint32 x = *a; return (x >> 24) | (x >> 8) & 0xff00 | (x << 8) & 0xff0000 | (x << 24);}
static inline uae_u16 do_get_mem_word(uae_u16 *a) {uint16 x = *a; return (x >> 8) | (x << 8);}
static inline uae_u8 do_get_mem_byte(uae_u8 *a) {return *a;}
static inline void do_put_mem_long(uae_u32 *a, uae_u32 v) {*a = (v >> 24) | (v >> 8) & 0xff00 | (v << 8) & 0xff0000 | (v << 24);}
static inline void do_put_mem_word(uae_u16 *a, uae_u16 v) {*a = (v >> 8) | (v << 8);}
static inline void do_put_mem_byte(uae_u8 *a, uae_u8 v) {*a = v;}
#else
static inline uae_u32 do_get_mem_long(uae_u32 *a) {uint8 *b = (uint8 *)a; return (b[0] << 24) | (b[1] << 16) | (b[2] << 8) | b[3];}
static inline uae_u16 do_get_mem_word(uae_u16 *a) {uint8 *b = (uint8 *)a; return (b[0] << 8) | b[1];}
static inline uae_u8 do_get_mem_byte(uae_u8 *a) {return *a;}
static inline void do_put_mem_long(uae_u32 *a, uae_u32 v) {uint8 *b = (uint8 *)a; b[0] = v >> 24; b[1] = v >> 16; b[2] = v >> 8; b[3] = v;}
static inline void do_put_mem_word(uae_u16 *a, uae_u16 v) {uint8 *b = (uint8 *)a; b[0] = v >> 8; b[1] = v;}
static inline void do_put_mem_byte(uae_u8 *a, uae_u8 v) {*a = v;}
#endif
#elif defined(CAN_ACCESS_UNALIGNED)
static inline uae_u32 do_get_mem_long(uae_u32 *a) {return *a;}
static inline uae_u16 do_get_mem_word(uae_u16 *a) {return *a;}
static inline uae_u8 do_get_mem_byte(uae_u8 *a) {return *a;}
static inline void do_put_mem_long(uae_u32 *a, uae_u32 v) {*a = v;}
static inline void do_put_mem_word(uae_u16 *a, uae_u16 v) {*a = v;}
static inline void do_put_mem_byte(uae_u8 *a, uae_u8 v) {*a = v;}
#else
static inline uae_u32 do_get_mem_long(uae_u32 *a) {uint8 *b = (uint8 *)a; return (b[0] << 24) | (b[1] << 16) | (b[2] << 8) | b[3];}
static inline uae_u16 do_get_mem_word(uae_u16 *a) {uint8 *b = (uint8 *)a; return (b[0] << 8) | b[1];}
static inline uae_u8 do_get_mem_byte(uae_u8 *a) {return *a;}
static inline void do_put_mem_long(uae_u32 *a, uae_u32 v) {uint8 *b = (uint8 *)a; b[0] = v >> 24; b[1] = v >> 16; b[2] = v >> 8; b[3] = v;}
static inline void do_put_mem_word(uae_u16 *a, uae_u16 v) {uint8 *b = (uint8 *)a; b[0] = v >> 8; b[1] = v;}
static inline void do_put_mem_byte(uae_u8 *a, uae_u8 v) {*a = v;}
#endif
#define call_mem_get_func(func, addr) ((*func)(addr))
#define call_mem_put_func(func, addr, v) ((*func)(addr, v))

#define __inline__ inline
#define CPU_EMU_SIZE 0
#undef USE_MAPPED_MEMORY
#undef CAN_MAP_MEMORY
#undef NO_INLINE_MEMORY_ACCESS
#undef MD_HAVE_MEM_1_FUNCS
#undef USE_COMPILER

// Win port redefines some of these file by file basis.
// Not cute, but avoids major code rewrites.
#define REGPARAM
#define REGPARAM2
#define REGPARAM3
#define ENUMDECL typedef enum
#define ENUMNAME(name) name
#define ASM_SYM_FOR_FUNC(a)

#endif
