/*
 *  prefs.h - Preferences handling
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#ifndef PREFS_H
#define PREFS_H

#include <stdio.h>

extern void PrefsInit(void);
extern void PrefsExit(void);

// Preferences loading/saving
extern void LoadPrefs(void);
extern void SavePrefs(void);

extern void LoadPrefsFromStream(FILE *f);
extern void SavePrefsToStream(FILE *f);

// Public preferences access functions
extern void PrefsAddString(const char *name, const char *s);
extern void PrefsAddBool(const char *name, bool b);
extern void PrefsAddInt16(const char *name, int16 val);
extern void PrefsAddInt32(const char *name, int32 val);

extern void PrefsReplaceString(const char *name, const char *s);
extern void PrefsReplaceBool(const char *name, bool b);
extern void PrefsReplaceInt16(const char *name, int16 val);
extern void PrefsReplaceInt32(const char *name, int32 val);

extern const char *PrefsFindString(const char *name, int index = 0);
extern bool PrefsFindBool(const char *name);
extern int16 PrefsFindInt16(const char *name);
extern int32 PrefsFindInt32(const char *name);

extern void PrefsRemoveItem(const char *name, int index = 0);


/*
 *  Definition of preferences items
 */

// Item types
enum prefs_type {
	TYPE_STRING,		// char[]
	TYPE_BOOLEAN,		// bool
	TYPE_INT16,			// int16
	TYPE_INT32,			// int32
	TYPE_ANY,			// Wildcard for find_node
	TYPE_END = TYPE_ANY	// Terminator for prefs_desc list
};

// Item descriptor
struct prefs_desc {
	const char *name;	// Name of keyword
	prefs_type type;	// Type (see above)
	bool multiple;		// Can this item occur multiple times (only for TYPE_STRING)?
};

// List of common preferences items (those which exist on all platforms)
extern prefs_desc common_prefs_items[];

// List of platform-specific preferences items
extern prefs_desc platform_prefs_items[];

#endif
