/*
 *  serial.h - Serial device driver
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#ifndef SERIAL_H
#define SERIAL_H

/*
 *  port:
 *    0 - .AIn
 *    1 - .AOut
 *    2 - .BIn
 *    3 - .BOut
 */

extern int16 SerialOpen(uint32 pb, uint32 dce, int port);
extern int16 SerialPrime(uint32 pb, uint32 dce, int port);
extern int16 SerialControl(uint32 pb, uint32 dce, int port);
extern int16 SerialStatus(uint32 pb, uint32 dce, int port);
extern int16 SerialClose(uint32 pb, uint32 dce, int port);

extern void SerialInterrupt(void);

// System specific and internal functions/data
extern void SerialInit(void);
extern void SerialExit(void);

// Serial driver Deferred Task structure
enum {
	serdtCode = 20,		// DT code is stored here
	serdtResult = 30,
	serdtDCE = 34,
	SIZEOF_serdt = 38
};

// Variables for one (In/Out combined) serial port
// To implement a serial driver, you create a subclass of SERDPort
class SERDPort {
public:
	SERDPort()
	{
		is_open = false;
		input_dt = output_dt = 0;
	}

	virtual int16 Open(uint16 config) = 0;
	virtual int16 PrimeIn(uint32 pb, uint32 dce) = 0;
	virtual int16 PrimeOut(uint32 pb, uint32 dce) = 0;
	virtual int16 Control(uint32 pb, uint32 dce, uint16 code) = 0;
	virtual int16 Status(uint32 pb, uint32 dce, uint16 code) = 0;
	virtual int16 Close(void) = 0;

	bool is_open;		// Port has been opened
	uint8 cum_errors;	// Cumulative errors

	bool read_pending;	// Read operation pending
	bool read_done;		// Read operation complete
	uint32 input_dt;	// Mac address of Deferred Task for reading

	bool write_pending;	// Write operation pending
	bool write_done;	// Write operation complete
	uint32 output_dt;	// Mac address of Deferred Task for writing
};

extern SERDPort *the_serd_port[2];

#endif
