/*
 *  video.h - Video/graphics emulation
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

#ifndef VIDEO_H
#define VIDEO_H

// Description for one (possibly virtual) monitor
enum {
	VMODE_1BIT,
	VMODE_2BIT,
	VMODE_4BIT,
	VMODE_8BIT,
	VMODE_16BIT,
	VMODE_32BIT
};

#define IsDirectMode(x) ((x) == VMODE_16BIT || (x) == VMODE_32BIT)

struct video_desc {
	uint32 mac_frame_base;	// Mac frame buffer address
	uint32 bytes_per_row;	// Bytes per row
	uint32 x;				// X size of screen (pixels)
	uint32 y;				// Y size of screen (pixels)
	int mode;				// Video mode
};

extern struct video_desc VideoMonitor;	// Description of the main monitor, set by VideoInit()

extern bool BlankMousePointer;			// Flag: Blank Mac mouse pointer (rom_patches.cpp uses this)

extern int16 VideoOpen(uint32 pb, uint32 dce);
extern int16 VideoControl(uint32 pb, uint32 dce);
extern int16 VideoStatus(uint32 pb, uint32 dce);

// System specific and internal functions/data
extern bool VideoInit(void);
extern void VideoExit(void);

extern void VideoInterrupt(void);

extern void video_set_palette(uint8 *pal);

#endif
