/*
 *  user_strings.cpp - Localizable strings
 *
 *  Basilisk II (C) 1997-1999 Christian Bauer
 */

/*
 *  NOTES:
 *
 *  This should only be used for user-interface related messages that must be
 *  translated or transcibed for localized versions of Basilisk.
 *  It should NOT be used for:
 *   - file names
 *   - names of threads, areas, ports, semaphores, drivers, views and other "invisible" names
 *   - debugging messages
 *   - error messages that only go to the shell ("FATAL"/"WARNING", those are really debugging messages)
 */

#include "sysdeps.h"
#include "user_strings.h"


struct str_def {
	int num;
	char *str;
};


// Localized strings
#if 0
static const str_def loc_strings[] = {
	{STR_READING_ROM_FILE, "ROM-Datei wird gelesen...\n"},
	{-1, NULL}	// End marker
};
#else
static const str_def loc_strings[] = {
	{-1, NULL}	// End marker
};
#endif


// Default strings
static const str_def default_strings[] = {
	{STR_ABOUT_TEXT1, "Basilisk II V%d.%d"},
	{STR_ABOUT_TEXT2, "by Christian Bauer et al."},
	{STR_READING_ROM_FILE, "Reading ROM file...\n"},
	{STR_SHELL_ERROR_PREFIX, "ERROR: %s\n"},
	{STR_GUI_ERROR_PREFIX, "Basilisk II error:\n%s"},
	{STR_ERROR_ALERT_TITLE, "Basilisk II Error"},
	{STR_SHELL_WARNING_PREFIX, "WARNING: %s\n"},
	{STR_GUI_WARNING_PREFIX, "Basilisk II warning:\n%s"},
	{STR_WARNING_ALERT_TITLE, "Basilisk II Warning"},
	{STR_NOTICE_ALERT_TITLE, "Basilisk II Notice"},
	{STR_OK_BUTTON, "OK"},
	{STR_START_BUTTON, "Start"},
	{STR_QUIT_BUTTON, "Quit"},
	{STR_CANCEL_BUTTON, "Cancel"},

	{STR_NO_MEM_ERR, "Not enough free memory."},
	{STR_NOT_ENOUGH_MEMORY_ERR, "Your computer does not have enough memory to run Basilisk II."},
	{STR_NO_RAM_AREA_ERR, "Not enough memory to create RAM area."},
	{STR_NO_ROM_AREA_ERR, "Not enough memory to create ROM area."},
	{STR_NO_ROM_FILE_ERR, "Cannot open ROM file."},
	{STR_ROM_FILE_READ_ERR, "Cannot read ROM file."},
	{STR_ROM_SIZE_ERR, "Invalid ROM file size. Basilisk II requires a 512K or 1MB MacII ROM."},
	{STR_UNSUPPORTED_ROM_TYPE_ERR, "Unsupported ROM type."},
	{STR_OPEN_WINDOW_ERR, "Cannot open Mac window."},
	{STR_OPEN_SCREEN_ERR, "Cannot open Mac screen."},
	{STR_SCSI_BUFFER_ERR, "Cannot allocate SCSI buffer (requested %d bytes). Giving up."},
	{STR_SCSI_SG_FULL_ERR, "SCSI scatter/gather table full. Giving up."},

	{STR_SMALL_RAM_WARN, "Selected less than 1MB Mac RAM, using 1MB."},

	{STR_WINDOW_TITLE, "Basilisk II"},
	{STR_WINDOW_TITLE_FROZEN, "Basilisk II *** FROZEN ***"},
	{STR_WINDOW_MENU, "Basilisk II"},
	{STR_WINDOW_ITEM_ABOUT, "About Basilisk II..."},
	{STR_WINDOW_ITEM_REFRESH, "Refresh Rate"},
	{STR_WINDOW_ITEM_MOUNT_FLOPPY, "Mount Floppy"},
	{STR_WINDOW_ITEM_DEBUGGER, "Debugger"},
	{STR_REF_5HZ_LAB, "5 Hz"},
	{STR_REF_7_5HZ_LAB, "7.5 Hz"},
	{STR_REF_10HZ_LAB, "10 Hz"},
	{STR_REF_15HZ_LAB, "15 Hz"},
	{STR_REF_30HZ_LAB, "30 Hz"},
	{STR_REF_60HZ_LAB, "60 Hz"},

	{STR_NO_SHEEP_DRIVER_ERR, "Cannot open /dev/sheep: %s (%08x). Basilisk II is not properly installed."},
	{STR_SHEEP_UP_ERR, "Cannot allocate Low Memory Globals: %s (%08x)."},
	{STR_NO_KERNEL_DATA_ERR, "Cannot create Kernel Data area: %s (%08x)."},
	{STR_VOLUME_IS_MOUNTED_WARN, "The volume '%s' is mounted under BeOS. Basilisk II will try to unmount it."},
	{STR_CANNOT_UNMOUNT_WARN, "The volume '%s' could not be unmounted. Basilisk II will not use it."},
	{STR_NO_NET_ADDON_WARN, "The SheepShaver net server add-on cannot be found. Ethernet will not be available."},
	{STR_NET_CONFIG_MODIFY_WARN, "To enable Ethernet networking for Basilisk II, your network configuration has to be modified and the network restarted. Do you want this to be done now (selecting \"Cancel\" will disable Ethernet under Basilisk II)?."},
	{STR_NET_ADDON_INIT_FAILED, "SheepShaver net server add-on found\nbut there seems to be no network hardware.\nPlease check your network preferences."},
	{STR_NET_ADDON_CLONE_FAILED, "Cloning of the network transfer area failed."},

	{STR_NO_XSERVER_ERR, "Cannot connect to X server '%s'."},
	{STR_NO_XVISUAL_ERR, "Cannot obtain appropriate X visual."},
	{STR_UNSUPP_DEPTH_ERR, "Unsupported color depth of screen."},
	{STR_NO_SHEEP_NET_DRIVER_ERR, "Cannot open /dev/sheep_net (%s). Ethernet will not be available."},
	{STR_SHEEP_NET_ATTACH_ERR, "Cannot attach to Ethernet card (%s). Ethernet will not be available."},

	{STR_NO_PREPARE_EMUL_ERR, "PrepareEmul is not installed. Run PrepareEmul and then try again to start Basilisk II."},
	{STR_NO_TIMER_DEV_ERR, "Cannot open timer.device."},
	{STR_NO_P96_MODE_ERR, "The selected screen mode is not a Picasso96 mode."},
	{STR_WRONG_SCREEN_DEPTH_ERR, "Basilisk II only supports 8, 16 or 24 bit screens."},
	{STR_WRONG_SCREEN_FORMAT_ERR, "Basilisk II only supports big-endian chunky ARGB screen modes."},
	{STR_NOT_ETHERNET_WARN, "The selected network device is not an Ethernet device. Networking will be disabled."},
	{STR_NO_MULTICAST_WARN, "Your Ethernet card does not support multicast and is not usable with AppleTalk. Please report this to the manufacturer of the card."},

	{-1, NULL}	// End marker
};


/*
 *  Fetch pointer to string, given the string number
 */

char *GetString(int num)
{
	// First search for localized string
	int i = 0;
	while (loc_strings[i].num >= 0) {
		if (loc_strings[i].num == num)
			return loc_strings[i].str;
		i++;
	}

	// Not found, then get default string
	i = 0;
	while (default_strings[i].num >= 0) {
		if (default_strings[i].num == num)
			return default_strings[i].str;
		i++;
	}
	return NULL;
}
